/*-------------------------------------------------------------------------
*
* hostregclient.h
*
*-------------------------------------------------------------------------
*/

#include "postgres.h"

#ifdef AZURE_SERVICE_FABRIC

#include "xdbendpoints.h"

#define XDB_WORKERPG_DATA_PACKAGE L"Data"
#define XDB_SQL_CONFIG_PACKAGE L"SQL.Config"
#define XDB_INSTANCE_SERVICE_TYPE L"PostgreSQL.Server.RS"

typedef void (WINAPI *tpfnPrimaryLoss)(__in BOOL fAbort);
typedef void XDBWinFabGlobals;
typedef void IFabricStatefulServicePartition;

/*
 * NAME: HostReg_Initialize
 *
 * PURPOSE:
 *	  Initialize the fabric runtime.
 *
 * RETURNS: S_OK if success
 *
 * NOTES:
 */
HRESULT
HostReg_Initialize(__inout_opt XDBWinFabGlobals **ppGlobals, __in_z LPCWSTR pszDefaultConfigPackageName);

/*
 * NAME: HostReg_Initialize
 *
 *	  Initialize the fabric runtime.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_GetNodeName(__out LPCWSTR *ppszValue);

/*
 * NAME: HostReg_GetDataDirectory
 *
 *	  PURPOSE:
 *	  Read data directory.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_GetDataDirectory(__in LPCWSTR pszDataPackage,
						__inout IUnknown **ppUnk,
						__out LPCWSTR* ppszValue);

/*
 * NAME: HostReg_GetWorkDirectory
 *
 *	  PURPOSE:
 *	  Read work directory.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_GetWorkDirectory(__out LPCWSTR *ppszValue);

/*
 * NAME: HostReg_GetPort
 *
 *	  PURPOSE:
 *	  Read port number.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_GetPort(__in LPCWSTR pszEndpoint, __out ULONG *pulPort);

/*
 * NAME: HostReg_ReadConfigurationSetting
 *
 *	  PURPOSE:
 *	  Read configuration setting.
 *	  Callers are responsible for memory release in ppszValue. 
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
WCHAR*
HostReg_ReadConfigurationSetting(__in const WCHAR* pwszPackage,
								__in const WCHAR* pwszSection,
								__in LPCWSTR pszSetting,
								__out HRESULT* pHrResult);

/*
 * NAME: HostReg_RegisterEndpoint
 *
 *	 PURPOSE:
 *	  Registers endpoint with XDB host.
 *
 *	  RETURNS: S_OK if success
 */
HRESULT
HostReg_RegisterEndpoint(__in LPCWSTR pszInstance,
							 __in LPCWSTR pszLogicalServer,
							 __in LONG cEndpoints,
							 __in_ecount(cEndpoints) const XdbEndpointType *prgeEndpoints,
							 __in_ecount(XDB_ENDPOINT_COUNT) const LONG *prglCustomPorts,
							 __in_opt LPCWSTR pszPipeSuffix,
							__out LPWSTR *ppszEndpoint);

typedef void (WINAPI *tRgClient_SetMetricReportingInterface)(__in void* partition);

/*
 * NAME: HostReg_RegisterInstanceService
 *
 *	  PURPOSE:
 *	  Register instance service and waits for replica placement.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_RegisterInstanceService(__in const WCHAR* pwszServiceTypeName,
									   __in LPCWSTR pszEndpoint,
									   __in tpfnPrimaryLoss pfnPrimaryLoss,
									   __in tRgClient_SetMetricReportingInterface pfnRgClient_SetMetricReportingInterface,
									   __in BOOL fWait,
									   __out_opt ULONGLONG *pullInstanceId1,
									 __out_opt ULONGLONG *pullInstanceId2,
									  __out_opt LONGLONG *pllReplicaId,
									 __out_opt GUID * pPartitionID);

/*
 * NAME: HostReg_BootedInstanceService
 *
 *	  PURPOSE:
 *	  Notify the instance service boot finished.
 *
 *	  RETURNS: S_OK if success
 *
 *	  NOTES:
 */
HRESULT
HostReg_BootedInstanceService();

/*
 * NAME: RgClient_SetMetricReportingInterface
 *
 *	  Description:
 *	  Sets service fabric interface for reporting metrics
 */
void
RgClient_SetMetricReportingInterface(
_In_opt_ IFabricStatefulServicePartition * partition);

/*
 * NAME: RgClient_RegisterResourceGovernance
 *
 *	  Description:
 *	  Register and waits for RgHost registration.
 *
 *	  Returns:
 *	  S_OK if success
 *
 *	  Notes:
 *	  If the _Out_ parameter "*ppbParamData" is not NULL then consumer needs to deallocate the Heap.
 */
HRESULT
RgClient_RegisterResourceGovernance(
_Out_opt_ BYTE** ppbParamData,
_Out_opt_ ULONG* pcbParamsData);

/*
 * Function: RgClient_Initialize
 *
 *	  Description:
 *	..Initialize the fabric runtime.
 *
 *	  Returns:
 *	  S_OK if success
 */
HRESULT
RgClient_Initialize(
_In_opt_ XDBWinFabGlobals **globals,
_In_z_ const wchar_t* defaultConfigPackageName,
_In_z_ const wchar_t* xeventsDataPackageName,
_In_z_ const wchar_t* clientApplicationName);

#endif






