/*-------------------------------------------------------------------------
 *
 * servicefabric.h
 *	  Header for service fabric initalization functions.
 *
 *-------------------------------------------------------------------------
*/

#ifndef SERVICE_FABRIC_H
#define SERVICE_FABRIC_H

#ifdef AZURE_SERVICE_FABRIC

/*
 * Common return code to be output from the postmaster process when 
 * process exits due to Service Fabric registration issue.
 */
#define SERVICE_FABRIC_POSTMASTER_EXIT_CODE 5
#define SERVICE_FABRIC_FIXED_PG_PORT 5435

/*
 * Attempt to initialize the Service Fabric runtime and register with 
 * Resource Governor.
 * Parameters:
 *   pszDataFolder - [in/out] Provides a pre-allocated buffer where data folder value can be stored.
 *   cchDataFolder - [in] Provides a size of the buffer represented by pszDataFolder.
 */
HRESULT
InitFabric(char *pszDataFolder, int cchDataFolder);

/*
 * Initializes the server globals passed by service fabric
 */
HRESULT
InitXdbSrvGlobals();

/*
 * Initializes and validates the location of data folder for this postgres server.
 * Parameters:
 *   pszWorkFolder  - [in] string value representing the 'work' folder for the Service Fabric application instance
 *   ppszDataFolder - [out] returns the location of the data folder. The buffer is allocated inside the method and 
 *                    needs to be freed by the caller 
 */
HRESULT
InitDataFolder(const char* pszWorkFolder, char** ppszDataFolder);

/*
* Function: NotifyFabricReadyForConnections
*
* Description:
* Notifies the server host communication stack is ready.
*
* Returns:
* HRESULT
*
*/
HRESULT
NotifyFabricReadyForConnections();

/*
* Checks if Setup was successful
*/
HRESULT
ValidateSetupEntryPointWasSuccessful(char* dataDir);

#endif

#endif