/*-------------------------------------------------------------------------
 *
 * xdbserverglobals.h
 *	  This file contains strictly those globals that XDB "owns" but live inside
 *	  the sqlservr.exe process.
 *
 *-------------------------------------------------------------------------
 */

#ifndef XDB_SERVER_GLOBALS_H
#define XDB_SERVER_GLOBALS_H

#ifdef AZURE_SERVICE_FABRIC

/*
 * Config settings being read for postgres.exe.
 */
#define XDB_SQL_CONFIG_PACKAGE L"SQL.Config"

#define XDB_CONFIG_SQL L"SQL"
#define XDB_CONFIG_SQL_BACKUP_PATH L"BackupPath"
#define XDB_CONFIG_SQL_COLLATION L"Collation"
#define XDB_CONFIG_SQL_DATA_PATH L"DataPath"
#define XDB_CONFIG_SQL_LOGICAL_SERVER_NAME L"LogicalServerName"
#define XDB_CONFIG_SQL_INSTANCE_NAME L"InstanceName"
#define XDB_CONFIG_SQL_PORT L"Port"
#define XDB_CONFIG_SQL_SECRET_NAME L"SecretName"

#define XDB_CONFIG_SQL_USES_LANGUAGE_LOCKDOWN L"UsesLanguageLockdown"
#define XDB_CONFIG_SQL_TRUST_SERVER_CERTIFICATE L"TrustServerCertificate"
#define XDB_CONFIG_IS_XDB_ONEBOX L"IsXdbOnebox"

#define XDB_CONFIG_CLUSTER L"Cluster"
#define XDB_CONFIG_CLUSTER_ADDRESS L"ClusterAddress"
#define XDB_CONFIG_GLOBAL_CLUSTER_ADDRESS L"Global"
#define XDB_CONFIG_CLUSTER_ZONE L"ClusterZone"


/*
 * Settings extracted from payloads in initialization data and naming service.
 */
#define XDB_INSTANCE_NODE L"instance"

typedef WCHAR LPWSTR_MAX[MAX_PATH + 1];

typedef struct XdbServerGlobals
{
	/*
	 * Cluster settings.
	 */
	LPWSTR_MAX          GlobalServerNameW; /* logical server name (short) */
	LPWSTR_MAX          GlobalServerFullNameW; /* logical server name (full) */
	LPWSTR_MAX          GlobalClusterZoneW; /* cluster zone */
	LPWSTR_MAX          GlobalClusterNameW; /* cluster name (short) */
	LPWSTR_MAX          GlobalClusterFullNameW; /* cluster name (full) */

	LPWSTR_MAX          InstanceName;

	/*
	 * Windows Fabric Service endpoint.
	 */
	LPCWSTR             ServiceEndpoint;
		
	/*
	 * Logical server instance type and db edition.
	 */
	BOOL                UseLanguageLockdown;
	LPWSTR_MAX          Edition;
	
	/*
	 * Resource pool dtu limit
	 */
	UINT32              ResourcePoolDtuLimit;

	/*
	 * Logical resource pool name
	 */
	LPWSTR_MAX          LogicalResourcePoolName;

	/*
	 * WinFab Service Partition Details
	 */
	GUID                InstancePartitionId;
	LONGLONG            InstanceReplicaId;

}XdbServerGlobals ;

extern int primaryReplicaLockFile;

#endif

#endif